# This file has been generated


build_system = 'AppVeyor'
build_id = '30815759'
build_number = '596'
build_version = '1.0.596'
job_id = 'lyqj21uv1f6jcvra'
job_url = 'https://ci.appveyor.com/project/KyleAltendorf/pm/build/job/lyqj21uv1f6jcvra'



# This file was automatically generated by sub\epyqlib\epyqlib\cli\generateversion.py
__version_build_time__ = '2020-02-14T23:50:28.585853'

__version__ = '2020.2.4'
__sha__ = '2adb20727073da5ad1cc5e1c94fa2a292b664834'
__revision__ = '2adb20727073da5ad1cc5e1c94fa2a292b664834'
